LSsca module — pySAXS 77.September2012 documentation

### Navigation

- index
- modules |
- previous |
- pySAXS 77.September2012 documentation »

# LSsca module

## `pySAXS.LS.LSsca` Module

pySAXS python routines for small angle xray scattering. This is the core of pySAXS containing usefull function for SAXS data treatment, tested and optimized amplitude and form factor

`pySAXS.LS.LSsca.` `Cubedre`(a, L)

  return the 3D coordinates of the 6 submits of a cube

`pySAXS.LS.LSsca.` `Dalpha`(par)

  This function returns a modified lognormal distribution for the array r with an averaga size rm and a standard deviation sigma

`pySAXS.LS.LSsca.` `Decaedre`(a, b)

  returne the 3D cartesian coordinates of the seven sumits of decahedra

`pySAXS.LS.LSsca.` `Dexpon`(par)

  This function returns a modified lognormal distribution for the array r with an averaga size rm and a standard deviation sigma

`pySAXS.LS.LSsca.` `Dgauss`(par)

  This function returns a gaussian distribution for the array r with an averaga size rm and a standard deviation sigma.

`pySAXS.LS.LSsca.` `Dlognormal`(par)

  This function returns a modified lognormal distribution for the array r with an averaga size rm and a standard deviation sigma

`pySAXS.LS.LSsca.` `Doublet_Multiplet`(a)

`pySAXS.LS.LSsca.` `Dshultz`(r, rav, z)

  This function returns a shultz distribution for the array r with rav, z as parameter

`pySAXS.LS.LSsca.` `F1`(q, R)

  This function returns a scattering amplitude of a sphere of radius R for q

`pySAXS.LS.LSsca.` `F2`(q, R1, R2)

  This function returns a scattering amplitude of an empty shell of internal radius R2 and external radius R2 for q

`pySAXS.LS.LSsca.` `F3`(q, R, rho)

  This function returns the scattering amplitude of spherically symetric shells of internal radius Ri and scattering length density rhoi for q

`pySAXS.LS.LSsca.` `F3elli`(q, R, e, rho)

`pySAXS.LS.LSsca.` `FaceTri`(R)

  return the 5 faces of the triedre

`pySAXS.LS.LSsca.` `FacesDeca`(R)

  return the faces of the decaedra R

`pySAXS.LS.LSsca.` `FacesHexa`(R)

  return the faces of the hexaedre_cyl R, fonctionne pour le deforme egalement

`pySAXS.LS.LSsca.` `FacesHexa_creux_def`(R, Rin)

  return the faces of the hexaedre_cyl R

`pySAXS.LS.LSsca.` `FacesTetraedre`(R)

  returns the faces of the tetraedre

`pySAXS.LS.LSsca.` `Facescube`(R)

  return the 6 faces of the Cubedre

`pySAXS.LS.LSsca.` `Faceshexaedre`(R)

  returns the 6 faces of the hexaedre

`pySAXS.LS.LSsca.` `Facesoctaedre`(R)

  returns the faces of the octaedre

`pySAXS.LS.LSsca.` `Guinier`(q, I0, Rg)

  Guinier function

`pySAXS.LS.LSsca.` `Hexaedre`(a)

  returns the 3D coordinates of the 8 summits of an hexaedre side length a

`pySAXS.LS.LSsca.` `Hexaedre_cyl`(a, L)

  return the 3D coordinates of the 12 submits of an hexaedre_cyl

`pySAXS.LS.LSsca.` `Hexaedre_def`(a, b, L)

  return the 3D coordinates of the 12 submits of an hexaedre_cyl deforme (a,b) au lieu de (a,a)

`pySAXS.LS.LSsca.` `Idqc`(q, rho1, rho2, rho3, al1, al2, al3, Phi1, Phi2, RG0, RGsig, R1, sigR1, R3, sigR3, taoL, taoS, scale, reduc)

`pySAXS.LS.LSsca.` `Multiplet`(q, L, rho, R)

`pySAXS.LS.LSsca.` `Normale`(Face)

  returns the oriented and normalized normal to the face

`pySAXS.LS.LSsca.` `Octaedre`(a)

  returns the 3D coordinates of the 6 summits of a octaaedre of side length a

`pySAXS.LS.LSsca.` `P1`(q, R)

  This function returns the form factor of a sphere of radius R for q

`pySAXS.LS.LSsca.` `P11`(q, R, L)

`pySAXS.LS.LSsca.` `P11_int`(q, R, L)

`pySAXS.LS.LSsca.` `P1Sqdist`(q, type, rm, sigma, eta, tao)

  This function returns the form factor of a dsitribution of spheres of radius R for q

`pySAXS.LS.LSsca.` `P1dist`(q, Dfunc, par)

  This function returns the form factor of a dsitribution of spheres of radius R for q

`pySAXS.LS.LSsca.` `P2`(q, R1, R2)

  This function returns the form factor of an empty shell of internal radius R2 and external radius R2 for q

`pySAXS.LS.LSsca.` `P3`(q, R, rho)

  This function returns the form factor of spherically symetric shells of internal radius Ri and scattering length density rhoi for q

`pySAXS.LS.LSsca.` `P3elli`(q, R, e, rho)

  This function returns the form factor of spherically symetric shells of internal radius Ri and scattering length density rhoi for q

`pySAXS.LS.LSsca.` `P5`(q, R, e)

  This function returns the form factor of an ellipsoid of revolution with semi-axes R, R and e*R for q

`pySAXS.LS.LSsca.` `P5_conc_int`(q, R, e, rho)

`pySAXS.LS.LSsca.` `P5_int`(q, R, e)

`pySAXS.LS.LSsca.` `P5conc`(q, R, e, rho)

  This function returns the form factor of an concentric ellipsoid of revolutions with semi-axes R, R and e*R for q

`pySAXS.LS.LSsca.` `P5dist`(q, type, rm, sigma, e)

  This function returns the form factor of a dsitribution of ellipses with semi-axes R, R and e*R for q

`pySAXS.LS.LSsca.` `PS`(a, b)

  return the scalar product of two vetors

`pySAXS.LS.LSsca.` `PV`(u, v)

  return the vector orthogonal to u and v

`pySAXS.LS.LSsca.` `Pcyl`(q, R, L)

  Optimized version of P11 OS This function calculates the P(q) of a cylinder of length L and radius R

`pySAXS.LS.LSsca.` `Pcylcos`(q, R, L)

  Optimized version of P11 OS This function calculates the P(q) of a cylinder of length L and radius R

`pySAXS.LS.LSsca.` `Pcylcouche`(q, rho, R, L)

  This function calculates the scaled by volume square and scattering length density P(q) of a cylinder of inner length L1 and radius R1 and outer length L2 and radius R2. It is thus more versatile than Pcylcreux

`pySAXS.LS.LSsca.` `Pcylcreux`(q, Ri, Ro, L)

  This function calculates the P(q) normalized to one at q=0 of an hollow cylinder of length L inner radius Ri and outer radius Ro

`pySAXS.LS.LSsca.` `Pcylcreuxcan`(q, a, Ri, Ro, L)

`pySAXS.LS.LSsca.` `Pcylcreuxqcq`(q, Ri, L, alp, b, x0, delt)

  contient une erreur en date du 30 avril 2009 connue mais a corriger This function calculates the P(q) normalized to one at q=0 of an hollow cylinder of length L inner radius Ri and outer radius Ro

`pySAXS.LS.LSsca.` `Pcylh`(q, R, L)

  Optimized version of P11 OS This function calculates the P(q) of a cylinder of length L and radius R with two hemispheres of redaisu R as cap ends is associated with dPcylh

`pySAXS.LS.LSsca.` `Pcylmulti`(q, R, rho, L, rhos)

  This function calculates at the absolute scale the P(q) of a cylinder of length L and and multilayers R of density Rho the last one being solvent

`pySAXS.LS.LSsca.` `Pcylvb`(q, R, L)

  This function calculates the P(q) normalized to one at q=0 of a cylinder of length L and radius R

`pySAXS.LS.LSsca.` `PdqHexa3`(q, R, L, N)

`pySAXS.LS.LSsca.` `PdqHexacoq`(q, Ri, Ro, L, N)

`pySAXS.LS.LSsca.` `Pdqhexa`(q, a, N)

`pySAXS.LS.LSsca.` `Pdqocta`(q, a, N)

`pySAXS.LS.LSsca.` `Pdqpoly`(q1, FacePoly, sign, N)

`pySAXS.LS.LSsca.` `Pdqtetra`(q, a, N)

`pySAXS.LS.LSsca.` `PolyGauss_ana_Norm`(q, par)

  This fucntion calculates the normalized P(q) of a gaussian distribution of spheres centered in par[0] with an extension par[1] q array of q (A-1) par[0] Mean radius(A) par[1] Gaussian standard deviation (A)

`pySAXS.LS.LSsca.` `PolySphere_int`(q, Dfunc, par)

`pySAXS.LS.LSsca.` `Porod`(q, B)

  Porod function q**-4*B*1e-32

`pySAXS.LS.LSsca.` `Ppara`(q, a, b, c)

  This function calculates the P(q) normalized to one at q=0 of a parallelepiped a,b,c (not finished 21/10/2009. this function makes use of dPpara which makes the integral over alpha

`pySAXS.LS.LSsca.` `ProjSommets`(Face)

`pySAXS.LS.LSsca.` `Qlogspace`(qmin, qmax, np)

  This function returns an array of np q values evenlly separated in log scale between qmin and qmax

`pySAXS.LS.LSsca.` `R`(R, L, x, alp, b, x0)

`pySAXS.LS.LSsca.` `SHexa`(R, L)

`pySAXS.LS.LSsca.` `SS`(f, p)

  This function returns the specific surface of a distribution of spheres f function to compute the distribution p array of parameter

`pySAXS.LS.LSsca.` `Scyl`(R, L)

`pySAXS.LS.LSsca.` `SqSticky`(q, R, eta, tao)

  This function computes the Baxter structure factor eta is the volume fraction tao is the sticky factor R is the radius in A q is an array of scattering vectors A-1

`pySAXS.LS.LSsca.` `Surf`(S)

`pySAXS.LS.LSsca.` `TFS`(Sommets, a, b, qx, qy)

  returns the ff of polygon for a matrix qx,qy

`pySAXS.LS.LSsca.` `TFSpi`(Sommets, a, b, qx, qy)

  returns the ff of polygon for a matrix qx,qy

`pySAXS.LS.LSsca.` `TFSs`(Sommets, a, b, qx, qy)

  returns the ff of polygon for a scalar qx qy

`pySAXS.LS.LSsca.` `Tetra1_Multiplet`(b)

  b is the distance between spheres

`pySAXS.LS.LSsca.` `Tetra2_Multiplet`(c)

  c is the distance between the core and the satellites

`pySAXS.LS.LSsca.` `Tetra_Multiplet`(a)

  semble suspect

`pySAXS.LS.LSsca.` `Tetraedre`(a)

  returns the 3D coordinates of the 4 summits of a tetraedreof side length a

`pySAXS.LS.LSsca.` `Triedre`(a, L)

  return the 3D coordinates of the 6 submits of a triedre

`pySAXS.LS.LSsca.` `Triplet_Multiplet`(a)

`pySAXS.LS.LSsca.` `VHexa`(R, L)

`pySAXS.LS.LSsca.` `Vcyl`(R, L)

`pySAXS.LS.LSsca.` `Vcylcreuxcan`(a, Ri, Ro, L)

`pySAXS.LS.LSsca.` `Vcylcreuxqcq`(Ri, L, alp, b, x0, delt)

`pySAXS.LS.LSsca.` `amplitude_multiplet`(q, L, rho, R)

`pySAXS.LS.LSsca.` `angle`(teta, phi)

`pySAXS.LS.LSsca.` `dPcylb`(qi, R, L, al)

`pySAXS.LS.LSsca.` `dPcylh`(qi, R, L, al)

  Subfunction of Pcylh

`pySAXS.LS.LSsca.` `dPpara`(q, a, b, c, beta)

  Side function of Ppara

`pySAXS.LS.LSsca.` `ddPcylh`(qi, R, al)

  Sub-sub-function of dPcylh

`pySAXS.LS.LSsca.` `distance`(A, B)

`pySAXS.LS.LSsca.` `f`(x, y)

`pySAXS.LS.LSsca.` `fP11_int`(x, q, R, L)

`pySAXS.LS.LSsca.` `fP5_conc_int`(x, q, R, e, rho)

`pySAXS.LS.LSsca.` `fP5_int`(x, q, R, e)

`pySAXS.LS.LSsca.` `fPolySphere_int`(R, q, Dfunc, Arg)

`pySAXS.LS.LSsca.` `fcan`(x, y, z)

`pySAXS.LS.LSsca.` `fcanb`(x, y, z)

`pySAXS.LS.LSsca.` `getRmoydist`(R, D)

  This function returns the form factor of a dsitribution of spheres of radius R for q

`pySAXS.LS.LSsca.` `getV`(R)

  This function returns a the volume of a sphere with radius r

`pySAXS.LS.LSsca.` `getVelli`(R, e)

  This function returns a the volume of a sphere with radius r

`pySAXS.LS.LSsca.` `pente`(Sommets)

`pySAXS.LS.LSsca.` `qvectors`(q, teta, phi)

`pySAXS.LS.LSsca.` `qvectorspi`(q, teta, phi)

### Navigation

- index
- modules |
- previous |
- pySAXS 77.September2012 documentation »